@@ -1,11 +1,11 @@
 package Net::DNS;
 
 #
-# $Id: DNS.pm 1221 2014-06-13 21:02:16Z willem $
+# $Id: DNS.pm 1256 2014-08-22 22:02:17Z willem $
 #
 use vars qw($VERSION $SVNVERSION);
-$VERSION    = '0.77';
-$SVNVERSION = (qw$LastChangedRevision: 1221 $)[1];
+$VERSION    = '0.79';
+$SVNVERSION = (qw$LastChangedRevision: 1256 $)[1];
 
 
 =head1 NAME
@@ -32,7 +32,6 @@ details.
 use 5.004_04;
 use strict;
 use integer;
-use Carp;
 
 use base qw(Exporter);
 use vars qw(@EXPORT);
@@ -198,7 +197,7 @@ if (OLDDNSSEC) {
 	}
 
 	eval {
-		no warnings 'void';	## suppress "Too late to run INIT block ..."
+		#no warnings 'void';	## DIY patch to suppress "Too late to run INIT block ..."
 
 		sub INIT {		## only needed to satisfy DNSSEC t/00-load.t
 			return unless OLDDNSSEC;
@@ -212,15 +211,15 @@ if (OLDDNSSEC) {
 }
 
 
+require Carp;
+require Net::DNS::Parameters;
+
 my $warned;
 
 sub deprecated {
-	carp "deprecated @_" unless $warned++;
+	Carp::carp "deprecated @_" unless $warned++;
 }
 
-
-require Net::DNS::Parameters;
-
 sub typesbyname {
 	deprecated('typesbyname; use Net::DNS::Parameters::typebyname') unless OLDDNSSEC;
 
