@@ -1,16 +1,16 @@
 package Net::DNS::Parameters;
 
 #
-# $Id: Parameters.pm 1222 2014-06-24 12:30:08Z willem $
+# $Id: Parameters.pm 1246 2014-08-14 19:39:22Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1222 $)[1];
+$VERSION = (qw$LastChangedRevision: 1246 $)[1];
 
 
 ################################################
 ##
 ##	Domain Name System (DNS) Parameters
-##	(last updated 2014-06-16)
+##	(last updated 2014-08-12)
 ##
 ################################################
 
@@ -104,6 +104,7 @@ use vars qw( %typebyname %typebyval );
 	TALINK	   => 58,					#
 	CDS	   => 59,					# RFC-ietf-dnsop-delegation-trust-maintainance-14
 	CDNSKEY	   => 60,					# RFC-ietf-dnsop-delegation-trust-maintainance-14
+	OPENPGPKEY => 61,					# draft-ietf-dane-openpgpkey
 	SPF	   => 99,					# RFC7208
 	UINFO	   => 100,					# IANA-Reserved
 	UID	   => 101,					# IANA-Reserved
@@ -175,14 +176,14 @@ use vars qw( %rcodebyname %rcodebyval );
 # Registry: DNS EDNS0 Option Codes (OPT)
 use vars qw( %ednsoptionbyname %ednsoptionbyval );
 %ednsoptionbyname = (
-	LLQ		     => 1,				# http://files.dns-sd.org/draft-sekar-dns-llq.txt
-	UL		     => 2,				# http://files.dns-sd.org/draft-sekar-dns-ul.txt
-	NSID		     => 3,				# RFC5001
-	DAU		     => 5,				# RFC6975
-	DHU		     => 6,				# RFC6975
-	N3U		     => 7,				# RFC6975
-	'EDNS-CLIENT-SUBNET' => 8,				# draft-vandergaast-edns-client-subnet
-	'EDNS-EXPIRE'	     => 9,				# RFC-andrews-dnsext-expire-04
+	LLQ		=> 1,					# http://files.dns-sd.org/draft-sekar-dns-llq.txt
+	UL		=> 2,					# http://files.dns-sd.org/draft-sekar-dns-ul.txt
+	NSID		=> 3,					# RFC5001
+	DAU		=> 5,					# RFC6975
+	DHU		=> 6,					# RFC6975
+	N3U		=> 7,					# RFC6975
+	'CLIENT-SUBNET' => 8,					# draft-vandergaast-edns-client-subnet
+	EXPIRE		=> 9,					# RFC7314
 	);
 %ednsoptionbyval = reverse %ednsoptionbyname;
 %ednsoptionbyname = ( %ednsoptionbyname, map /\D/ ? lc($_) : $_, %ednsoptionbyname );
