@@ -1,12 +1,14 @@
 package Net::DNS::RR::SSHFP;
 
 #
-# $Id: SSHFP.pm 1068 2012-12-06 10:38:51Z willem $
+# $Id: SSHFP.pm 1188 2014-04-03 18:54:34Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1068 $)[1];
+$VERSION = (qw$LastChangedRevision: 1188 $)[1];
 
-use base Net::DNS::RR;
+
+use strict;
+use base qw(Net::DNS::RR);
 
 =head1 NAME
 
@@ -15,7 +17,6 @@ Net::DNS::RR::SSHFP - DNS SSHFP resource record
 =cut
 
 
-use strict;
 use integer;
 
 use constant BABBLE => eval { require Digest::BubbleBabble; };
@@ -44,8 +45,8 @@ sub format_rdata {			## format rdata portion of RR string.
 	return '' unless $self->{fpbin};
 	my $babble	= $self->babble;
 	my $fingerprint = $self->fp;
-	$fingerprint =~ s/(\S{64})/$1\n/g;
 	$fingerprint = "(\n$fingerprint )" if length $fingerprint > 40;
+	$fingerprint =~ s/(\S{64})/$1\n/g;
 	return join ' ', $self->algorithm, $self->fptype, $fingerprint unless $babble;
 	return join ' ', $self->algorithm, $self->fptype, $fingerprint, "\n;", $babble;
 }
@@ -54,7 +55,8 @@ sub format_rdata {			## format rdata portion of RR string.
 sub parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
-	$self->$_(shift) for qw(algorithm fptype);
+	$self->algorithm(shift);
+	$self->fptype(shift);
 	$self->fp(@_);
 }
 
@@ -62,31 +64,35 @@ sub parse_rdata {			## populate RR from rdata in argument list
 sub algorithm {
 	my $self = shift;
 
-	$self->{algorithm} = shift if @_;
-	return 0 + ( $self->{algorithm} || 0 );
+	$self->{algorithm} = 0 + shift if scalar @_;
+	return $self->{algorithm} || 0;
 }
 
+
 sub fptype {
 	my $self = shift;
 
-	$self->{fptype} = shift if @_;
-	return 0 + ( $self->{fptype} || 0 );
+	$self->{fptype} = 0 + shift if scalar @_;
+	return $self->{fptype} || 0;
 }
 
+
 sub fp {
 	my $self = shift;
 
-	$self->{fpbin} = pack "H*", map { s/\s+//g; $_ } join "", @_ if @_;
-	unpack "H*", $self->{fpbin} || "" if defined wantarray;
+	$self->fpbin( pack "H*", map { die "!hex!" if m/[^0-9A-Fa-f]/; $_ } join "", @_ ) if scalar @_;
+	unpack "H*", $self->fpbin() if defined wantarray;
 }
 
+
 sub fpbin {
 	my $self = shift;
 
-	$self->{fpbin} = shift if @_;
+	$self->{fpbin} = shift if scalar @_;
 	$self->{fpbin} || "";
 }
 
+
 sub babble {
 	return Digest::BubbleBabble::bubblebabble( Digest => shift->fpbin ) if BABBLE;
 	return '';
@@ -106,7 +112,7 @@ __END__
 
 =head1 DESCRIPTION
 
-DNS SSH Fingerprint (SSHFP) resource records - RFC 4255.
+DNS SSH Fingerprint (SSHFP) resource records.
 
 =head1 METHODS
 
@@ -121,6 +127,7 @@ other unpredictable behaviour.
 =head2 algorithm
 
     $algorithm = $rr->algorithm;
+    $rr->algorithm( $algorithm );
 
 The 8-bit algorithm number describes the algorithm used to
 construct the public key.
@@ -128,6 +135,7 @@ construct the public key.
 =head2 fptype
 
     $fptype = $rr->fptype;
+    $rr->fptype( $fptype );
 
 The 8-bit fingerprint type number describes the message-digest
 algorithm used to calculate the fingerprint of the public key.
@@ -135,12 +143,14 @@ algorithm used to calculate the fingerprint of the public key.
 =head2 fp
 
     $fp = $rr->fp;
+    $rr->fp( $fp );
 
 Hexadecimal representation of the fingerprint digest.
 
 =head2 fpbin
 
     $fpbin = $rr->fpbin;
+    $rr->fpbin( $fpbin );
 
 Returns opaque octet string representing the fingerprint digest.
 
@@ -169,13 +179,13 @@ when the string method is called.
 
 Copyright (c)2007 Olaf Kolkman, NLnet Labs.
 
-Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
-
 All rights reserved.
 
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
+Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+
 
 =head1 SEE ALSO
 
